@@ -1,5 +1,6 @@
 import time
 import os
+from pathlib import Path
 import numpy as np
 import pandas as pd
 import pickle
@@ -81,8 +82,6 @@ class LoggerCallback(Callback):
         self.results = []
         self.y_ep, self.y2_ep, self.stats_1, self.stats_2, self.t0, self.t1 = None, None, None, None, 0, 0
         self.df, self.df_best = None, None
-        print(f'Logging to {self.mode}')
-        if self.file: print(f'Logging to file: {self.fname}')
         pd.options.display.float_format = '{:,.4f}'.format
         
     def reset_stats(self):
@@ -109,18 +108,23 @@ class LoggerCallback(Callback):
         self.df = pd.DataFrame(self.results, columns=self.cols)
        
     def log_epoch(self):
-        if self.mode == 'ipynb' and self._plot and self.eps > 1:
+        if self.mode == 'ipynb' and self.show and self.eps > 1:
             x = self.df['Epoch'].values
             y = self.df[['Loss_1', 'Loss_2']].values
             y0, y1 = y[:,0], y[:,1] if self.data.dl2 is not None else None
             plot_update(self.fig, self.ax, x, y0, y1)
         s = log_str(self.ep, self.t2, self.loss1, self.loss2, self.metrics1, self.metrics2, self.new_best, valid=self.data.dl2 is not None)
-        print(s)
+        if self.show: print(s)
 
     def begin_fit(self):
         if self.data.dl2 is None: self.best = 1e9
-        if self.mode == 'ipynb' and self._plot and self.eps > 1: self.fig, self.ax = plot_init(0, self.eps)
+        if self.mode == 'ipynb' and self.show and self.eps > 1: self.fig, self.ax = plot_init(0, self.eps)
         self.cols = ['Epoch', 'Time', 'Loss_1'] + [f'{e.__name__}_1' for e in self.metrics] + ['Loss_2'] + [f'{e.__name__}_2' for e in self.metrics]
+        if self.show:
+            if self.file:
+                print(f'Logging to file: {self.fname}')
+            else:
+                print(f'Logging to {self.mode}')
         
     def begin_epoch(self):
         self.t0 = time.time()
@@ -135,7 +139,7 @@ class LoggerCallback(Callback):
         with torch.no_grad(): self.accumulate()
         
     def after_batch(self):
-        printProgressBar(self.iter, self.iters, f'Ep: {self.ep:d} {"train" if self.train else "eval"}:')
+        if self.show: printProgressBar(self.iter, self.iters, f'Ep: {self.ep:d} {"train" if self.train else "eval"}:')
 
     def after_epoch(self):
         self.t2 = time.time() - self.t0 if self.t0 is not None else time.time()
@@ -161,7 +165,7 @@ class LoggerCallback(Callback):
             if self._save: self.save()
         
     def after_fit(self):
-        print(f'\nBest: {self.best:.4f}')
+        if self.show: print(f'\nBest: {self.best:.4f}')
         plt.ioff()
 
     def show_best(self): display(self.df_best)
